require 'rubygems'
require 'yaml'
require 'optparse'
require 'amqp'
require 'json'

$:.push File.expand_path("../lib")

require 'manband/workflow.rb'
require 'manband/flowconfig.rb'
require 'manband/job.rb'
require 'manband/bandmanager.rb'
require 'manband/util.rb'

# The program sends a workflow execution request to manband orchestrator.
# Author: Olivier Sallou <olivier.sallou@irisa.fr>
# Copyright: 2012, IRISA

log = Logger.new(STDOUT)
log.level = Logger::INFO

options = {}

optparse = OptionParser.new do|opts|
  
  # This displays the help screen, all programs are
  # assumed to have this option.
  opts.on( '-h', '--help', 'Display this screen' ) do
    puts opts
    exit
  end

  opts.on( '-s', '--show WORKFLOW', 'show workflow with id WORKFLOW') do  |workflow|
    workflow = WorkFlow.get(workflow)
    puts "Workflow "+workflow.id.to_s
    puts " -- start: "+workflow.created_at.to_s
    puts " -- end  : "+workflow.terminated_at.to_s
    jobs = Job.all(:wid => workflow.id)
    jobs.each do |job|
      if job.node != "root"
        puts " ---- "+job.id.to_s+","+job.node+","+job.status.to_s
        puts " ------ Workdir: "+job.workdir   unless job.workdir == nil
        puts " ------ Handler: "+job.handler   unless job.handler == nil
      end
    end
  end


  options[:workflow] = nil
  opts.on( '-w', '--workflow FILE', 'Use input worflow') do |file|
    puts "using "+file
    options[:workflow] = file
  end

  options[:conf] = nil
  opts.on( '-c', '--conf CONFIG', 'Use config file' ) do |config|
    options[:conf] = config
  end


  options[:uid] = 'admin'
  opts.on( '-u', '--user UID', 'User id') do |uid|
    options[:uid] = uid
  end

  options[:bucket] = 'manband'
  opts.on( '-b', '--bucket BUCKET', 'S3 bucket if storage is used') do |bucket|
    options[:bucket] = bucket
  end

  options[:var] = Array.new
  opts.on( '-v', '--var KEY1=VAL1,KEY2=VAL2,KEY3=VAL3', Array, 'Runtime variables') do |runtimevars|
    options[:var] = runtimevars
  end

  options[:debug] = false
  opts.on( '-d', '--debug', 'Debug mode, do not execute commands') do
    options[:debug] = true
  end
end

optparse.parse!

if options[:workflow]==nil
  exit
end

userconf = File.expand_path("~")+"/.manband"
if options[:conf]==nil && File.exists?(userconf)
  options[:conf]=userconf
end

if options[:conf]!=nil
  if !File.exists?(options[:conf])
    puts "Config file does not exists"
    exit 1
  end
  conf = YAML.load_file(options[:conf])
  puts "Using configuration file "+options[:conf]
  FlowConfig.setworkdir(conf["workdir"])
end


wid = BandManager.launch(options[:workflow],options[:var],options[:uid],options[:bucket],options[:debug])

if wid == nil
  log.error "Could not launch the workflow"
else
  log.info "Workflow "+wid.to_s+" starting..."
end
