require 'rubygems'
require 'yaml'
require 'optparse'
require 'amqp'
require 'json'
require 'logger'

$:.push File.expand_path("../lib")

require 'manband/flowconfig.rb'
require 'manband/util.rb'


# The program sends a workflow execution request to manband orchestrator.
# This program does not need database credentials but does not get workflow id in return
# Author: Olivier Sallou <olivier.sallou@irisa.fr>
# Copyright: 2012, IRISA


log = Logger.new(STDOUT)
log.level = Logger::INFO

options = {}

optparse = OptionParser.new do|opts|
  
  # This displays the help screen, all programs are
  # assumed to have this option.
  opts.on( '-h', '--help', 'Display this screen' ) do
    puts opts
    exit
  end

  opts.on( '-s', '--show WORKFLOW', 'show workflow with id WORKFLOW') do  |workflow|
    workflow = WorkFlow.get(workflow)
    puts "Workflow "+workflow.id.to_s
    puts " -- start: "+workflow.created_at.to_s
    puts " -- end  : "+workflow.terminated_at.to_s
    jobs = Job.all(:wid => workflow.id)
    jobs.each do |job|
      if job.node != "root"
        puts " ---- "+job.id.to_s+","+job.node+","+job.status.to_s
        puts " ------ Workdir: "+job.workdir   unless job.workdir == nil
        puts " ------ Handler: "+job.handler   unless job.handler == nil
      end
    end
  end


  options[:workflow] = nil
  opts.on( '-w', '--workflow FILE', 'Use input worflow') do |file|
    puts "using "+file
    options[:workflow] = file
  end

  options[:uid] = 'admin'
  opts.on( '-u', '--user UID', 'User id') do |uid|
    options[:uid] = uid
  end

  options[:var] = Array.new
  opts.on( '-v', '--var KEY1=VAL1,KEY2=VAL2,KEY3=VAL3', Array, 'Runtime variables') do |runtimevars|
    options[:var] = runtimevars
  end

  options[:bucket] = 'manband'
  opts.on( '-b', '--bucket BUCKET', 'S3 bucket if storage is used') do |bucket|
    options[:bucket] = bucket
  end


end

optparse.parse!

if options[:workflow]==nil
  exit
end

msg  = Hash.new
msg["wfile"]=options[:workflow]
msg["var"]=options[:var]
msg["uid"]=options[:uid]
msg["bucket"]=options[:bucket]


Utils.publish('manband.master',{ "operation" => "new", "msg" => msg.to_json })

urlconfig = FlowConfig.config()




