require 'rubygems'
require 'yaml'
require 'optparse'
require 'json'
require 'logger'

$:.push File.expand_path("../lib")

require 'manband/flowconfig.rb'

# The program is used to manage users (add, update) in the database.
# Users are used for web interface authentification and S3 credentials.
# Author: Olivier Sallou <olivier.sallou@irisa.fr>
# Copyright: 2012, IRISA


log = Logger.new(STDOUT)
log.level = Logger::INFO

user = nil

options = {}

optparse = OptionParser.new do|opts|
  
  # This displays the help screen, all programs are
  # assumed to have this option.
  opts.on( '-h', '--help', 'Display this screen' ) do
    puts opts
    exit
  end

  options[:login] = nil
  opts.on( '-u', '--user UID', 'User id') do |uid|
    options[:login] = uid
  end

  options[:password] = nil
  opts.on( '-p', '--password PASSWORD', 'User password') do |passwd|
    options[:password] = passwd
  end

  options[:access] = nil
  opts.on( '-a', '--access S3_ACCESS', 'S3 Access key') do |access|
    options[:access] = access
  end

  options[:secret] = nil
  opts.on( '-s', '--secret S3_SECRET', 'S3 secret key') do |secret|
    options[:secret] = secret
  end
end

optparse.parse!

if options[:login]==nil
  puts "User id is mandatory"
  exit
end

user = User.get(options[:login])

if user == nil
  user = User.new(:login => options[:login], :password => Digest::SHA1.hexdigest(options[:password]), :s3_access => options[:access], :s3_secret => options[:secret] )
  user.save
  log.info "User "+user.id+" created"
else
  if options[:password] == nil
    options[:password] = user.password
  end
  if options[:access] == nil
    options[:access] = user.s3_access
  end
  if options[:secret] == nil
    options[:secret] = user.s3_secret
  end
  user.update(:password => Digest::SHA1.hexdigest(options[:password]), :s3_access => options[:access], :s3_secret => options[:secret])
  log.info "User "+user.id.to_s+" updated"
end


