require 'uuid'
require 'data_mapper'
require 'dm-migrations'

# Configuration library

# Determines the workflow and node status
STATUS_SKIP = -2
STATUS_FAKE = -1
STATUS_NEW = 0
STATUS_RUNNING = 1
STATUS_OVER = 2
STATUS_SUSPEND = 3 # SUSPEND mode for a job means a job is over and paused
STATUS_ERROR = 4

# Determines if a job must be stored to S3, and its current status
STORE_NO = -1
STORE_DO = 0
STORE_RUN = 1
STORE_OVER = 2
STORE_ERROR = 4

# List of message operations
OP_NEW = "new"
OP_START = "start"
OP_FINISH = "finish"
OP_ERROR = "error"
OP_WSUSPEND = "workflowsuspend"
OP_JSUSPEND = "jobsuspend"
OP_RUN = "run"
OP_WRESUME = "workflowresume"
OP_JRESUME = "jobresume"
OP_SKIP = "skip" # For if conditions, go through jobs but skip execution
OP_CLEAN = "clean"  # Delete work dirs of workflow
OP_DESTROY = "destroy"  # Delete workflow and its work dirs
OP_STORE = "store" # Store result to S3

# Actors type are exclusive
# Basic actor
ACTOR = -1
# If actor, i.e. ony one of the following jobs will be executed. Selected job match the exit code of the command. Type of the node will be set to selected output
# WARNING: input of IF actors MUST NOT be a pattern matchng multiple files. The IF condition must be executed only once, not on a bunch of files.
IF_ACTOR = -2
# Interactive actor: there is no automatic FINISH message. Command is executed and user/an other script will send a FINISH message when appropriate.
INTERACTIVE_ACTOR = -3


# This class holds the base config
class FlowConfig
   @@workdir='/tmp'
   @@s3host = 'localhost'
   @@s3port = '8773'
   @@s3path = '/services/Walrus'

   @@uploaddir = '/tmp/upload'

   # Sudo commands
   @@sudo = false

   def self.sudo
     return @@sudo
   end

   # Sets sudo mode
   # If sudo is set, job commands are run with a sudo on user id.
   # User must exists on the system.
   #
   # Can be set in user config file with sudo: true
   def self.setsudo(dosudo)
     @@sudo = dosudo
   end

   def self.uploaddir
     return @@uploaddir
   end

   def self.s3host
     return @@s3host
   end

   # Sets S3 storage parameters
   #
   # Parameters can be set in user config fiel under s3 parameter
   def self.sets3(host,port= '8773',path='/services/Walrus')
     @@s3host = host
     @@s3port = port
     @@s3path = path
   end
  
   def self.s3port
     return @@s3port
   end

   def self.s3path
     return @@s3path
   end

   def self.workdir
     return @@workdir
   end

   # defines upload directory for webband
   # It must be accessible by the handlers
   def self.setuploaddir(directory)
     @@uploaddir = directory
   end

   # Defines the work directory. It must be shared between job
   # and workflow handlers.
   def self.setworkdir(directory)
     @@workdir=directory
   end


   # Returns a work directory for a job. Directory
   # is based on a unique identifier.
   def self.getjobdir(workflowdir = nil)
     uuid = UUID.new
     if workflowdir == nil
       return @@workdir+"/"+uuid.generate.to_s
     else
       return workflowdir+"/"+uuid.generate.to_s 
     end
   end

  def self.config
    url ||= (ENV["AMQP_URL"] || "amqp://guest:guest@localhost/")
    uri = URI.parse(url)
    {
      :vhost => uri.path,
      :host => uri.host,
      :user => uri.user,
      :port => (uri.port || 5672),
      :pass => uri.password,
      :heartbeat => 0
    }
    rescue Object => e
      raise("invalid AMQP_URL: #{uri.inspect} (#{e})")
  end



end

